/**
 * Svelte action to initialize semantic dropdown component.
 * @module components/use-dropdown
 */
import type { ActionReturnType } from "../data/common";
import type { DropdownSettings } from "../data/semantic-types";
import { SettingsHelper } from "../data/settings";
export declare const dropdownDefaults: SettingsHelper<DropdownSettings>;
/**
 * Initializes Semantic UI Dropdown component. Takes settings object as argument.
 *
 * https://semantic-ui.com/modules/dropdown.html#/settings
 *
 * Bind using `<Data bind:selected` inside the component tag.
 *
 * Example:
```
   <select class="ui selection dropdown" use:dropdown={{ clearable: true }}>
        <Data bind:selected={num} />
        ...
   </select>
```
 * For select-based component use standard labels.
 * For div-based dropdowns use `<label for="_"` inside the parent `<div class="field"`.
 *
 * NOTE: For multi-select, options will be removed and added one at a time,
 * causing multiple updates.
 * Though Svelte reaction is able to join consequitive updates into one, an additional update from
 * the component will be registered anyway. 'Confirming' values back, even if they didn't change.
 * If value is not in the list, it will be removed (not added).
*/
export declare function dropdown(node: Element, settings?: DropdownSettings): ActionReturnType;
