/**
 * Common types, jQuery API, Form and Data controllers, utility functions.
 * @module data/common
 */
export const SVELTE_DATA_STORE = "svelte_data_store";
export const SVELTE_FORM_STORE = "svelte_form_store";
/** Gets jQuery element by id attribute. */
export function jQueryElemById(id) {
    // eslint-disable-next-line @typescript-eslint/unbound-method, @typescript-eslint/typedef
    const jQuery = window.jQuery;
    if (!jQuery) {
        throw new Error("jQuery is not initialized");
    }
    return jQuery(`#${id}`);
}
/** Gets jQuery element by dom node. */
export function jQueryElem(node) {
    // eslint-disable-next-line @typescript-eslint/unbound-method, @typescript-eslint/typedef
    const jQuery = window.jQuery;
    if (!jQuery) {
        throw new Error("jQuery is not initialized");
    }
    return jQuery(node);
}
/*
            dP   oo dP
            88      88
 dP    dP d8888P dP 88
 88    88   88   88 88
 88.  .88   88   88 88
 `88888P'   dP   dP dP

*/
let unum = 100;
/** Generate an unique number */
export function uid() {
    // const num = new Date().getTime();
    // const num = Math.round(window.performance.now());
    unum = unum + 1;
    return `000000${unum % 1000}`.slice(-3);
}
/** Compare two arrays, two Date objects, or two primitives */
export function equalDataTypes(a1, a2) {
    if (Array.isArray(a1) && Array.isArray(a2)) {
        if (a1.length !== a2.length) {
            return false;
        }
        for (let i = 0; i < a1.length; i++) {
            if (a1[i] !== a2[i]) {
                return false;
            }
        }
        return true;
    }
    if (a1 instanceof Date && a2 instanceof Date) {
        return a1.getTime() === a2.getTime();
    }
    return a1 === a2;
}
export function pad(n, size) {
    let str = n.toString();
    while (str.length < size) {
        str = `0${str}`;
    }
    return str;
}
export function isoDate(d) {
    if (!d || !d.getDate) {
        return "";
    }
    const day = pad(d.getDate(), 2);
    const month = pad(d.getMonth() + 1, 2);
    const year = pad(d.getFullYear(), 4);
    return `${year}-${month}-${day}`;
}
export function isoTime(d) {
    if (!d || !d.getDate) {
        return "";
    }
    const hour = pad(d.getHours(), 2);
    const minute = pad(d.getMinutes(), 2);
    return `${hour}:${minute}`;
}
