/**
 * Svelte action to activate validation framework for the form.
 * @module data/use-form-validation
 */
import type { FormSettings } from "./semantic-types";
import { SettingsHelper } from "./settings";
export declare const formDefaults: SettingsHelper<FormSettings>;
/** Svelte action to initialize Semantic UI Form component with validation.
 *
 * https://semantic-ui.com/behaviors/form.html
 *
 * Example:
```
    <form class="ui form" use:suiFormValidation={{ inline: true }} />
        <input class="ui input"  />
        <Data bind:value={name} validate={"empty"} />
        ...
        <div class="ui message error" />
    </div>
```
 * Fields are matched by 'id', 'name', or 'data-validate' attribute.
 * Create `<div class="ui message error" />` to display the messages.
 *
 * For Dropdown, use id of the select or inner input.
 * For Calendar, use id of the innermost input.
*/
export declare function formValidation(node: Element, settings?: FormSettings): void;
